@@ -45,6 +45,36 @@ class AdminInvoices(admin.ModelAdmin):
         obj.total = obj.subtotal + obj.subtotal_iva + obj.subtotal_retentions
         obj.save()
 
+
+class BudgetLinesInline(admin.TabularInline):
+    model = mymodels.BudgetLine
+
+
+class AdminBudgets(admin.ModelAdmin):
+
+    list_display = ('customer', 'header', 'date', 'total', 'currency', 'get_PDF2')
+    inlines = [ BudgetLinesInline, ]
+    ordering = ('-date',)
+
+    """
+    Para agregar TinyMCE en los newforms-admin:
+    - http://code.djangoproject.com/wiki/AddWYSIWYGEditor#Withnewforms-admin
+    - http://code.djangoproject.com/wiki/AddWYSIWYGEditor
+    """
+
+    class Media:
+        js = ('js/tiny_mce/tiny_mce.js',
+              'js/textareas.js',
+              )
+
+    def get_PDF2(self, obj):
+        return '<a href="/rinvoices/budget_PDF/%s/es">PDFes</a>, <a href="/rinvoices/budget_PDF/%s/en">PDFen</a>, <a href="/rinvoices/budget_txtPDF/%s/es">TXTes</a>, <a href="/rinvoices/budget_txtPDF/%s/en">TXTen</a>' % (str(obj.id), str(obj.id), str(obj.id), str(obj.id))
+    get_PDF2.allow_tags = True
+
+    def save_model(self, request, obj, form, change):
+        obj.save()
+
+
 class AdminReceivedInvoices(admin.ModelAdmin):
 
     list_display = ('provider', 'reference', 'title', 'description', 'date', 'total', 'paid', 'registered')
@@ -60,3 +90,4 @@ admin.site.register(mymodels.Tax)
 admin.site.register(mymodels.Retention)
 admin.site.register(mymodels.QuantityUnit)
 admin.site.register(mymodels.Currency)
+admin.site.register(mymodels.Budget, AdminBudgets)
